<?php
// vim: set noexpandtab tabstop=2 softtabstop=2 shiftwidth=2:

/**
 * Chat plugin.
 * Displays player world statistics.
 * Created by Xymph
 *
 * Dependencies: requires includes/tmudatafetcher.inc.php
 */

require_once('includes/tmudatafetcher.inc.php'); // provides access to world stats

class StatsAll extends Plugin {

	function displayStatsAll($command) {

		// decide whether to get information about the command author,
		// or about a specified player
		if ($command['params'] != '') {
			$login = $command['params'];
		} else {
			$login = $command['author']->login;
		}

		// create window
		$window = $this->createWindowToPlayerFramework('Playerstatsall', 0.4, 0.4, $command['author']->login);
		// set window width
		$window->setWidth(0.8);

		// get player stats from the master server
		// set option to true to get/display zone stats as well
		$stats = new TMUDataFetcher($login, false);

		if ($stats->nickname != '') {
			$messages = array();
			$message = '';

			// build the world stats string
			$message .= '<line><cell width="0.798" bgcolor="333F"><text>$fffShowing World Statistics of $s' . stripFormatting($stats->nickname) . '</text></cell></line>';
			$message .= '<line><cell width="0.2"><text>$000Location</text></cell><cell width="0.6"><text>$00f' . $stats->location . '</text></cell></line>';
			$message .= '<line><cell width="0.2"><text>$000Rank</text></cell><cell width="0.6"><text>$f00' . $stats->worldrank . ' / ' . $stats->totalplayers . '</text></cell></line>';
			$message .= '<line><cell width="0.2"><text>$000Points</text></cell><cell width="0.6"><text>$f00' . $stats->points . '</text></cell></line>';
			$message .= '<line><cell width="0.2"><text>$000Last Score</text></cell><cell width="0.6"><text>$f00' . $stats->lastscore . '</text></cell></line>';
			$message .= '<line><cell width="0.2"><text>$000Wins</text></cell><cell width="0.6"><text>$f00' . $stats->wins . '</text></cell></line>';
			$message .= '<line><cell width="0.2"><text>$000Draws</text></cell><cell width="0.6"><text>$f00' . $stats->draws . '</text></cell></line>';
			$message .= '<line><cell width="0.2"><text>$000Losses</text></cell><cell width="0.6"><text>$f00' . $stats->losses . '</text></cell></line>';

			$messages[] = $message;

			foreach ($stats->envstats as $envname => $envstats) {
				$message = '';

				// build the env stats string
				$message .= '<line><cell width="0.798" bgcolor="333F"><text>$fffShowing ' . $envname . ' Statistics of $s' . stripFormatting($stats->nickname) . '</text></cell></line>';
				$message .= '<line><cell><text>$fff</text></cell></line>';  // filler
				$message .= '<line><cell width="0.2"><text>$000Rank</text></cell><cell width="0.6"><text>$f00' . $envstats['rank'] . ' / ' . $stats->totalplayers . '</text></cell></line>';
				$message .= '<line><cell width="0.2"><text>$000Points</text></cell><cell width="0.6"><text>$f00' . $envstats['points'] . '</text></cell></line>';
				$message .= '<line><cell width="0.2"><text>$000Last Score</text></cell><cell width="0.6"><text>$f00' . $envstats['lastscore'] . '</text></cell></line>';
				$message .= '<line><cell width="0.2"><text>$000Wins</text></cell><cell width="0.6"><text>$f00' . $envstats['wins'] . '</text></cell></line>';
				$message .= '<line><cell width="0.2"><text>$000Draws</text></cell><cell width="0.6"><text>$f00' . $envstats['draws'] . '</text></cell></line>';
				$message .= '<line><cell width="0.2"><text>$000Losses</text></cell><cell width="0.6"><text>$f00' . $envstats['losses'] . '</text></cell></line>';

				$messages[] = $message;
			}

			foreach ($stats->zonestats as $zonename => $zonestats) {
				$message = '';

				// build the zone stats string
				$message .= '<line><cell width="0.798" bgcolor="333F"><text>$fffShowing Zone Statistics of $s' . stripFormatting($stats->nickname) . '</text></cell></line>';
				$message .= '<line><cell width="0.2"><text>$000Zone</text></cell><cell width="0.6"><text>$00f' . $zonename . '</text></cell></line>';
				$message .= '<line><cell width="0.2"><text>$000Zone Rank</text></cell><cell width="0.6"><text>$f00' . $zonestats['zonerank'] . ' / ' . $zonestats['totalzones'] . '</text></cell></line>';
				$message .= '<line><cell width="0.2"><text>$000Zone Points</text></cell><cell width="0.6"><text>$f00' . $zonestats['zonepoints'] . '</text></cell></line>';
				$message .= '<line><cell width="0.2"><text>$000Player Rank</text></cell><cell width="0.6"><text>$f00' . $zonestats['playerrank'] . ' / ' . $zonestats['totalplayers'] . '</text></cell></line>';
				$message .= '<line><cell width="0.2"><text>$000Player Points</text></cell><cell width="0.6"><text>$f00' . $zonestats['playerpoints'] . '</text></cell></line>';
				$message .= '<line><cell><text>$fff</text></cell></line><line><cell><text>$fff</text></cell></line>';  // filler

				$messages[] = $message;
			}

			// set the window's content
			$window->setContent($messages);
		} else {
			// fault response
			$message = '<line><cell><text>$f00Notice: $000Player "' . $command['params'] . '" does not exist on the master server!</text></cell></line>';
			// set the window's content
			$window->setContent($message);
		}
	}
}

$_PLUGIN = new StatsAll();
$_PLUGIN->setAuthor('Xymph');
$_PLUGIN->setVersion(1.0);
$_PLUGIN->addChatCommand('statsall', 'displayStatsAll', 'shows world statistics for a player');
$_PLUGIN->setDescription('Gets world statistics of a specified player and displays them.');
?>
